    Audio test lib to compute audio quality and 3A performance by objective metrics
	pcm,wav inputfiles is allowed,support different samplerate (invalid params are simply corrected to valid ones)

    
    
    """
    :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS,
    # g160 no samplerate limiting,  WAV/PCM input , three inputfiles :clean,ref,test no duration limiting;
    # P563 8000hz( only 8k spectrum is being calculated), WAV/PCM input , single inputfile, duration < 20s;
    # POLQA nb mode  8k  swb mode 48k :WAV/PCM input , 2 inputfiles: ref,test: duration < 20s;
    # PESQ nb mode 8k   wb mode  16k ,WAV/PCM input ,2 inputfiles: ref,test: duration < 20s;
    # STOI no samplerate limiting; 2 inputfiles: ref,test, no duration limiting;
    # STI >8k(only 8k spectrum is being calculated), WAV/PCM input , 2 inputfiles: ref,test ,duration > 20s;
    # PEAQ no samplerate limiting, WAV/PCM ,2 inputfiles: ref, test , no duration limiting;
    # SDR no samplerate limiting; WAV/PCM input ,2 inputfiles:ref,test: no duration limiting;
 
	there are different params for different metrics,if params you speend is valid,they will be corrected to valid ones while calculating
    :param testFile: the files under test ,
    :param refFile: the reference file ,FR metrics need POLQA/PESQ/PEAQ
    :param cleFile: clean file ,G160 need 
    :param samplerate: samplerate,option ,pcmfile  default = 16000
    :param bitwidth: bitwidth, option,pcmfile  default = 2
    :param channel: channels, option,pcmfile  default = 1
    :param refOffset: offset for ref file,option
    :param testOffset: offset for test file ,option
    :return
    """

